R/data.R
countrycode.RdA dataset containing mapping of the country ISO code to the country names. More information on participating countries can be found at https://www.oecd.org/en/about/programmes/pisa/pisa-participants.html.
A tibble of the following variables
country: Country 3 character code. Note that some regions/territories are coded as country for ease of input. Character.
country_name: Country name. Note that some regions/territories are coded as country for ease of input. Character.